diff --git a/Scripts/Functions/Render/render_xhtml_convertToText.sh b/Scripts/Functions/Render/render_xhtml_convertToText.sh
index b0e1c22..6fa6b03 100755
--- a/Scripts/Functions/Render/render_xhtml_convertToText.sh
+++ b/Scripts/Functions/Render/render_xhtml_convertToText.sh
@@ -1,6 +1,6 @@
#!/bin/bash
#
# svg_convertHtmlToText.sh -- This function takes one HTML file
# and produces one plain-text file (i.e., without markup inside).
#
# Copyright (C) 2009, 2010, 2011 The CentOS Project
@@ -23,7 +23,7 @@
# $Id$
# ----------------------------------------------------------------------
-function xhtml_convertToText {
+function render_xhtml_convertToText {
# Verify existence of HTML file.
cli_checkFiles ${FILE}.xhtml
@@ -1,6 +1,6 @@
#!/bin/bash
#
-# svg_convertHtmlToText.sh -- This function takes one HTML file
+# render_svg_convertHtmlToText.sh -- This function takes one HTML file
# and produces one plain-text file (i.e., without markup inside).
#